Fabrial plugin for controlling a Quince 10 GCE lab oven [Fabrial](https://github.com/Maughan-Lab/fabrial.git).

## Categories

### Quince 10 GCE Lab Oven

Steps for controlling the oven.

#### `Set Setpoint`

Set the oven's setpoint and wait for the temperature to stabilize at the setpoint.

#### `Set Setpoint (No Stabilization)`

Set the oven's setpoint without waiting for the temperature to stabilize.

#### `Increment Setpoint`

Increment the oven's setpoint and wait the temperature to stabilize at the setpoint.

#### `Record Temperature`

Record the oven's current temperature once.

#### `Record Setpoint`

Record the oven's current setpoint once.